==> resource_planner-0.2.4.gem: app/assets/javascripts/resource_planner/form_fullcalendar_resource_manipulation.js <==
var selectedResources = [];

//  label (resource), body (timeline)
// TODO: selectedBackgroundColour values should come from the database
var unselectedBackgroundColour = ['rgba(0, 0, 0, 0)', 'rgba(0, 0, 0, 0)'];
//var selectedBackgroundColour = ['blue', 'cyan'];
var selectedBackgroundColour = ['blue', 'rgba(0, 0, 0, 0)'];
var conflictBackgroundColour = ['IndianRed', 'LightSalmon'];

$(document).ready(function () {
    // resource selection handler (see resourceRender callback in fullcalendar initialisation)

    // Initialise...
    renderSelectedResources();
});

function resourceSelectedHandler(resourceObj, labelTds, bodyTds) {
    var resourceId = resourceObj.id;

    var index = selectedResources.map(function (e) { return e.resourceId; }).indexOf(resourceId);
    if (index == -1) {
        var resourceData = {};
        resourceData.resourceId = resourceId;
        resourceData.isInConflict = false;
        resourceData.conflictingEvents = [];
        resourceData.conflictingRestrictions = [];

        selectedResources.push(resourceData);
    } else {
        selectedResources = selectedResources.filter(function (value, index, arr) {
            return value.resourceId != resourceId;
        });
    }

    renderSelectedResources();

    // labelTds.css('background', 'blue');
    // bodyTds.css('background', 'yellow');
    // resource_id = labelTds.parent().attr("data-resource-id");
    // labelTds.eq(0).find('.fc-cell-content')
    //   .append(
    //     $('<strong>('+resource_id+')</strong>')
    //     //$('<strong>(?)</strong>')
    //     //.popover({
    //     //  title: resourceObj.title,
    //     //  content: 'test!',
    //     //  trigger: 'hover',
    //     //  placement: 'bottom',
    //     //  container: 'body'
    //     //})
    //   );

    //console.clear();
    console.log('selectedResources:');
    console.log(selectedResources);
}

function renderSelectedResources() {
    // Clear all highlighting on resources
    $('.fc-resource-area [data-resource-id]').css('background-color', unselectedBackgroundColour[0]);
    $('.fc-time-area [data-resource-id]').css('background-color', unselectedBackgroundColour[1]);

    // Check for conflicts
    flagResourceConflicts();

    // Render event conflicts
    displayHighlighterConflicts();

    // Render resource conflicts
    for (var i = 0; i < selectedResources.length; i++) {
        var resourceAreaColour = (selectedResources[i].isInConflict) ? conflictBackgroundColour[0] : selectedBackgroundColour[0];
        var timeAreaColour = (selectedResources[i].isInConflict) ? conflictBackgroundColour[1] : selectedBackgroundColour[1];

        //$('.fc-resource-area [data-resource-id=' + selectedResources[i].resourceId + ']').find('.fc-widget-content').css('background-color', resourceAreaColour);
        $('.fc-resource-area [data-resource-id=' + selectedResources[i].resourceId + ']').css('background-color', resourceAreaColour);

        //$('.fc-time-area [data-resource-id=' + selectedResources[i].resourceId + ']').find('.fc-widget-content').css('background-color', timeAreaColour);
        $('.fc-time-area [data-resource-id=' + selectedResources[i].resourceId + ']').css('background-color', timeAreaColour);
    }
}

function flagResourceConflicts() {
    $.when(
        // Get existing events and resource restrictions
        $.ajax({ url: '/resource_planner/resource_events.json', async: false }),
        $.ajax({ url: '/resource_planner/resource_restrictions.json', async: false })
    ).done(function (a1, a2) {
        var existingEvents = a1[0];
        var resourceRestrictions = a2[0];

        // get currently planned event list (eventArray)
        var eventsArray = window.eventsArray

        // see where they conflict and flag the resource
        if (typeof eventsArray !== 'undefined') {

            // Clear active conflicts on the highlighter bar
            clearHighlighterConflicts();

            for (var selectedResourceindex = 0; selectedResourceindex < selectedResources.length; selectedResourceindex++) {

                selectedResources[selectedResourceindex].isInConflict = false;
                selectedResources[selectedResourceindex].conflictingEvents = [];
                selectedResources[selectedResourceindex].conflictingRestrictions = [];

                for (var eventArrayIndex = 0; eventArrayIndex < eventsArray.length; eventArrayIndex++) {

                    for (var i = 0; i < existingEvents.length; i++) {
                        if (existingEvents[i].resourceIds.indexOf(selectedResources[selectedResourceindex].resourceId) != -1) {
                            if (dateCheck(existingEvents[i].start, existingEvents[i].end, eventsArray[eventArrayIndex].startDate)
                                || dateCheck(existingEvents[i].start, existingEvents[i].end, eventsArray[eventArrayIndex].endDate)
                            ) {
                                selectedResources[selectedResourceindex].isInConflict = true;
                                var conflictingEvent = {};
                                conflictingEvent.id = existingEvents[i].id;
                                conflictingEvent.name = existingEvents[i].title;
                                selectedResources[selectedResourceindex].conflictingEvents.push(conflictingEvent);
                                eventsArray[eventArrayIndex].isInConflict = true;
                            }
                        }
                    }

                    for (var i = 0; i < resourceRestrictions.length; i++) {
                        if (resourceRestrictions[i].resourceIds.indexOf(selectedResources[selectedResourceindex].resourceId) != -1) {
                            if (dateCheck(resourceRestrictions[i].start, resourceRestrictions[i].end, eventsArray[eventArrayIndex].startDate)
                                || dateCheck(resourceRestrictions[i].start, resourceRestrictions[i].end, eventsArray[eventArrayIndex].endDate)
                            ) {
                                selectedResources[selectedResourceindex].isInConflict = true;
                                var conflictingRestriction = {};
                                conflictingRestriction.id = existingEvents[i].id;
                                conflictingRestriction.name = existingEvents[i].title;
                                selectedResources[selectedResourceindex].conflictingRestrictions.push(conflictingRestriction);
                                eventsArray[eventArrayIndex].isInConflict = true;
                            }
                        }
                    }

                }
            }
        }

        // Update the 'global' eventsArray
        window.eventsArray = eventsArray;
    });
}

==> resource_planner-0.2.6.gem: app/assets/javascripts/resource_planner/form_fullcalendar_resource_manipulation.js <==
var selectedResources = [];

//  label (resource), body (timeline)
// TODO: selectedBackgroundColour values should come from the database
var unselectedBackgroundColour = ['rgba(0, 0, 0, 0)', 'rgba(0, 0, 0, 0)'];
//var selectedBackgroundColour = ['blue', 'cyan'];
var selectedBackgroundColour = ['blue', 'rgba(0, 0, 0, 0)'];
var conflictBackgroundColour = ['IndianRed', 'LightSalmon'];

$(document).ready(function () {
    // resource selection handler (see resourceRender callback in fullcalendar initialisation)

    // Initialise...
    renderSelectedResources();
});

function resourceSelectedHandler(resourceObj, labelTds, bodyTds) {
    var resourceId = resourceObj.id;

    var index = selectedResources.map(function (e) { return e.resourceId; }).indexOf(resourceId);
    if (index == -1) {
        var resourceData = {};
        resourceData.resourceId = resourceId;
        resourceData.isInConflict = false;
        resourceData.conflictingEvents = [];
        resourceData.conflictingRestrictions = [];

        selectedResources.push(resourceData);
    } else {
        selectedResources = selectedResources.filter(function (value, index, arr) {
            return value.resourceId != resourceId;
        });
    }

    renderSelectedResources();

    // labelTds.css('background', 'blue');
    // bodyTds.css('background', 'yellow');
    // resource_id = labelTds.parent().attr("data-resource-id");
    // labelTds.eq(0).find('.fc-cell-content')
    //   .append(
    //     $('<strong>('+resource_id+')</strong>')
    //     //$('<strong>(?)</strong>')
    //     //.popover({
    //     //  title: resourceObj.title,
    //     //  content: 'test!',
    //     //  trigger: 'hover',
    //     //  placement: 'bottom',
    //     //  container: 'body'
    //     //})
    //   );

    //console.clear();
    console.log('selectedResources:');
    console.log(selectedResources);
}

function renderSelectedResources() {
    // Clear all highlighting on resources
    $('.fc-resource-area [data-resource-id]').css('background-color', unselectedBackgroundColour[0]);
    $('.fc-time-area [data-resource-id]').css('background-color', unselectedBackgroundColour[1]);

    // Check for conflicts
    flagResourceConflicts();

    // Render event conflicts
    displayHighlighterConflicts();

    // Render resource conflicts
    for (var i = 0; i < selectedResources.length; i++) {
        var resourceAreaColour = (selectedResources[i].isInConflict) ? conflictBackgroundColour[0] : selectedBackgroundColour[0];
        var timeAreaColour = (selectedResources[i].isInConflict) ? conflictBackgroundColour[1] : selectedBackgroundColour[1];

        //$('.fc-resource-area [data-resource-id=' + selectedResources[i].resourceId + ']').find('.fc-widget-content').css('background-color', resourceAreaColour);
        $('.fc-resource-area [data-resource-id=' + selectedResources[i].resourceId + ']').css('background-color', resourceAreaColour);

        //$('.fc-time-area [data-resource-id=' + selectedResources[i].resourceId + ']').find('.fc-widget-content').css('background-color', timeAreaColour);
        $('.fc-time-area [data-resource-id=' + selectedResources[i].resourceId + ']').css('background-color', timeAreaColour);
    }
}

function flagResourceConflicts() {
    $.when(
        // Get existing events and resource restrictions
        $.ajax({ url: '/resource_planner/resource_events.json', async: false }),
        $.ajax({ url: '/resource_planner/resource_restrictions.json', async: false })
    ).done(function (a1, a2) {
        var existingEvents = a1[0];
        var resourceRestrictions = a2[0];

        // get currently planned event list (eventArray)
        var eventsArray = window.eventsArray

        // see where they conflict and flag the resource
        if (typeof eventsArray !== 'undefined') {

            // Clear active conflicts on the highlighter bar
            clearHighlighterConflicts();

            for (var selectedResourceindex = 0; selectedResourceindex < selectedResources.length; selectedResourceindex++) {

                selectedResources[selectedResourceindex].isInConflict = false;
                selectedResources[selectedResourceindex].conflictingEvents = [];
                selectedResources[selectedResourceindex].conflictingRestrictions = [];

                for (var eventArrayIndex = 0; eventArrayIndex < eventsArray.length; eventArrayIndex++) {

                    for (var i = 0; i < existingEvents.length; i++) {
                        if (existingEvents[i].resourceIds.indexOf(selectedResources[selectedResourceindex].resourceId) != -1) {

                            var resourceQuantity = parseInt(selectedResources[selectedResourceindex].resourceId.split("-")[2], 10);

                            // TODO: Arbitrate for resourceQuantity > 1
                            if ( resourceQuantity > 0 &&
                                (dateCheck(existingEvents[i].start, existingEvents[i].end, eventsArray[eventArrayIndex].startDate)
                                || dateCheck(existingEvents[i].start, existingEvents[i].end, eventsArray[eventArrayIndex].endDate)
                                )
                            ) {
                                selectedResources[selectedResourceindex].isInConflict = true;
                                var conflictingEvent = {};
                                conflictingEvent.id = existingEvents[i].id;
                                conflictingEvent.name = existingEvents[i].title;
                                selectedResources[selectedResourceindex].conflictingEvents.push(conflictingEvent);
                                eventsArray[eventArrayIndex].isInConflict = true;
                            }
                        }
                    }

                    for (var j = 0; j < resourceRestrictions.length; j++) {
                        if (resourceRestrictions[j].resourceIds.indexOf(selectedResources[selectedResourceindex].resourceId) != -1) {
                            if (dateCheck(resourceRestrictions[j].start, resourceRestrictions[j].end, eventsArray[eventArrayIndex].startDate)
                                || dateCheck(resourceRestrictions[j].start, resourceRestrictions[j].end, eventsArray[eventArrayIndex].endDate)
                            ) {
                                selectedResources[selectedResourceindex].isInConflict = true;
                                var conflictingRestriction = {};
                                conflictingRestriction.id = existingEvents[j].id;
                                conflictingRestriction.name = existingEvents[j].title;
                                selectedResources[selectedResourceindex].conflictingRestrictions.push(conflictingRestriction);
                                eventsArray[eventArrayIndex].isInConflict = true;
                            }
                        }
                    }

                }
            }

            // Update the 'global' eventsArray
            window.eventsArray = eventsArray;
        }
    });
}
